@@ -1,8 +1,10 @@
+"""
+专栏相关
+"""
 
-
+from typing import List, overload
 from bilibili_api.utils.utils import get_api
 from bilibili_api.utils.Credential import Credential
-import json
 import re
 
 import yaml
@@ -10,54 +12,53 @@ from bilibili_api.utils.network import get_session, request
 from bilibili_api.exceptions.NetworkException import NetworkException, ApiException
 from bs4 import BeautifulSoup, element
 from datetime import datetime
-from bilibili_api.utils.Color import Color
-from copy import copy
 from urllib.parse import unquote
 
 API = get_api('article')
 
 
 ARTICLE_COLOR_MAP = {
-    'blue-01': Color('56c1fe'),
-    'lblue-01': Color('73fdea'),
-    'green-01': Color('89fa4e'),
-    'yellow-01': Color('fff359'),
-    'pink-01': Color('ff968d'),
-    'purple-01': Color('ff8cc6'),
+    'blue-01': '56c1fe',
+    'lblue-01': '73fdea',
+    'green-01': '89fa4e',
+    'yellow-01': 'fff359',
+    'pink-01': 'ff968d',
+    'purple-01': 'ff8cc6',
 
-    'blue-02': Color('02a2ff'),
-    'lblue-02': Color('18e7cf'),
-    'green-02': Color('60d837'),
-    'yellow-02': Color('fbe231'),
-    'pink-02': Color('ff654e'),
-    'purple-02': Color('ef5fa8'),
+    'blue-02': '02a2ff',
+    'lblue-02': '18e7cf',
+    'green-02': '60d837',
+    'yellow-02': 'fbe231',
+    'pink-02': 'ff654e',
+    'purple-02': 'ef5fa8',
 
-    'blue-03': Color('0176ba'),
-    'lblue-03': Color('068f86'),
-    'green-03': Color('1db100'),
-    'yellow-03': Color('f8ba00'),
-    'pink-03': Color('ee230d'),
-    'purple-03': Color('cb297a'),
+    'blue-03': '0176ba',
+    'lblue-03': '068f86',
+    'green-03': '1db100',
+    'yellow-03': 'f8ba00',
+    'pink-03': 'ee230d',
+    'purple-03': 'cb297a',
 
-    'blue-04': Color('004e80'),
-    'lblue-04': Color('017c76'),
-    'green-04': Color('017001'),
-    'yellow-04': Color('ff9201'),
-    'pink-04': Color('b41700'),
-    'purple-04': Color('99195e'),
+    'blue-04': '004e80',
+    'lblue-04': '017c76',
+    'green-04': '017001',
+    'yellow-04': 'ff9201',
+    'pink-04': 'b41700',
+    'purple-04': '99195e',
 
-    'gray-01': Color('d6d5d5'),
-    'gray-02': Color('929292'),
-    'gray-03': Color('5f5f5f'),
+    'gray-01': 'd6d5d5',
+    'gray-02': '929292',
+    'gray-03': '5f5f5f',
 }
 
+
 async def get_article_list(rlid: int, credential: Credential = None):
     """
     获取专栏文集文章列表
 
     Args:
-        rlid (int): 文集 ID，如 https://www.bilibili.com/read/readlist/rl000010 省略前导 0
-        credential (Credential, optional): [description]. Defaults to None.
+        rlid       (int)                 : 文集 ID，如 https: //www.bilibili.com/read/readlist/rl000010 省略前导 0
+        credential (Credential, optional): 凭据. Defaults to None.
     """
     credential = credential if credential is not None else Credential()
 
@@ -67,11 +68,21 @@ async def get_article_list(rlid: int, credential: Credential = None):
     }
     return await request('GET', api['url'], params, credential=credential)
 
+
 class Article:
+    """
+    专栏类
+    """
+
     def __init__(self, cvid: int, credential: Credential = None):
-        self.children = []
-        self.credential = credential if credential is not None else Credential()
-        self.meta = {
+        """
+        Args:
+            cvid       (int)                 : cv 号
+            credential (Credential, optional): 凭据. Defaults to None.
+        """
+        self.__children: List[Node] = []
+        self.credential: Credential = credential if credential is not None else Credential()
+        self.__meta = {
             "title": None,
             "author_name": None,
             "author_space": None,
@@ -79,46 +90,60 @@ class Article:
             "banner": None,
             "category": None,
             "tags": None,
-            "cvid": cvid
+            "cvid": None
         }
-        self._has_parsed = False
+        self.cvid = cvid
+        self.__has_parsed: bool = False
 
     def markdown(self):
         """
-        转换为 Markdon
+        转换为 Markdown
+
+        请先调用 get_content()
 
         Returns:
-            str
+            str: Markdown 内容
         """
-        if not self._has_parsed: raise ApiException('请先调用 get_content()')
+        if not self.__has_parsed:
+            raise ApiException('请先调用 get_content()')
 
-        content = "".join([node.markdown() for node in self.children])
+        content = "".join([node.markdown() for node in self.__children])
 
-        meta_yaml = yaml.safe_dump(self.meta, allow_unicode=True)
+        self.__meta['cvid'] = self.cvid
+        meta_yaml = yaml.safe_dump(self.__meta, allow_unicode=True)
         content = f"---\n{meta_yaml}\n---\n\n{content}"
         return content
 
     def json(self):
         """
         转换为 JSON 数据
-        """
-        if not self._has_parsed: raise ApiException('请先调用 get_content()')
 
+        请先调用 get_content()
+
+        Returns:
+            dict: JSON 数据
+        """
+        if not self.__has_parsed:
+            raise ApiException('请先调用 get_content()')
+
+        self.__meta['cvid'] = self.cvid
         return {
             "type": "Article",
-            "meta": self.meta,
-            "children": list(map(lambda x: x.json(), self.children))
+            "meta": self.__meta,
+            "children": list(map(lambda x: x.json(), self.__children))
         }
 
-    async def get_content(self):
+    async def fetch_content(self):
         """
-        解析专栏内容
+        获取并解析专栏内容
 
-        Args:
-            cv (int): [description]
+        该返回不会返回任何值，调用该方法后请再调用 `self.markdown()` 或 `self.json()` 来获取你需要的值。
+
+        Returns:
+            None
         """
         session = get_session()
-        resp = await session.get(f'https://www.bilibili.com/read/cv{self.meta["cvid"]}')
+        resp = await session.get(f'https://www.bilibili.com/read/cv{self.cvid}')
 
         resp.raise_for_status()
         html = (await resp.read()).decode()
@@ -136,10 +161,11 @@ class Article:
 
             head_el: BeautifulSoup = document.select_one('.title-container')
 
-            meta['cvid'] = self.meta['cvid']
+            meta['cvid'] = self.__meta['cvid']
 
             # 标题
-            meta['title'] = document.select_one('.title-container .title').contents[0].strip()
+            meta['title'] = document.select_one(
+                '.title-container .title').contents[0].strip()
 
             # 分区
             category_el: BeautifulSoup = head_el.select_one('.category-name')
@@ -147,7 +173,8 @@ class Article:
 
             # 发布时间
             ctime_el: BeautifulSoup = head_el.select_one('.publish-text')
-            meta['ctime'] = datetime.strptime(ctime_el.contents[0].strip(), "%Y-%m-%d").strftime("%Y-%m-%d")
+            meta['ctime'] = datetime.strptime(
+                ctime_el.contents[0].strip(), "%Y-%m-%d").strftime("%Y-%m-%d")
 
             author_el: BeautifulSoup = document.select_one('.article-up-info')
 
@@ -159,7 +186,8 @@ class Article:
             meta['author_space'] = 'https:' + author_name_el.attrs['href']
 
             # 头图
-            meta['banner'] = document.select_one('meta[property="og:image"]').attrs['content']
+            meta['banner'] = document.select_one(
+                'meta[property="og:image"]').attrs['content']
 
             # 标签
             tags_items_el = document.select('.article-tags .tag-item')
@@ -232,7 +260,8 @@ class Article:
                             node = FontSizeNode()
                             node_list.append(node)
 
-                            node.size = int(re.search('font-size-(\d\d)', className)[1])
+                            node.size = int(
+                                re.search('font-size-(\d\d)', className)[1])
                             node.children = parse(e)
 
                         elif 'color' in className:
@@ -240,8 +269,9 @@ class Article:
                             node = ColorNode()
                             node_list.append(node)
 
-                            color_text = re.search('color-(.*);?', className)[1]
-                            node.color = copy(ARTICLE_COLOR_MAP[color_text])
+                            color_text = re.search(
+                                'color-(.*);?', className)[1]
+                            node.color = ARTICLE_COLOR_MAP[color_text]
 
                             node.children = parse(e)
 
@@ -327,9 +357,11 @@ class Article:
                                 node = ImageNode()
                                 node_list.append(node)
 
-                                node.url = "https:" + e.find('img').attrs['data-src']
+                                node.url = "https:" + \
+                                    e.find('img').attrs['data-src']
 
-                                figcaption_el: BeautifulSoup = e.find('figcaption')
+                                figcaption_el: BeautifulSoup = e.find(
+                                    'figcaption')
 
                                 if figcaption_el.contents:
                                     node.alt = figcaption_el.contents[0]
@@ -340,7 +372,8 @@ class Article:
                             node_list.append(node)
 
                             pre_el: BeautifulSoup = e.find('pre')
-                            node.lang = pre_el.attrs['data-lang'].split('@')[0].lower()
+                            node.lang = pre_el.attrs['data-lang'].split('@')[
+                                0].lower()
                             node.code = unquote(pre_el.attrs['codecontent'])
 
                 elif e.name == 'ol':
@@ -385,13 +418,13 @@ class Article:
             return node_list
 
         # 解析文章元数据
-        self.meta = find_meta()
+        self.__meta = find_meta()
 
         # 解析正文
         body = document.select_one('#read-article-holder')
-        self.children =  parse(body)
+        self.__children = parse(body)
 
-        self._has_parsed = True
+        self.__has_parsed = True
 
     async def get_info(self):
         """
@@ -400,11 +433,10 @@ class Article:
 
         api = API["info"]["view"]
         params = {
-            "id": self.meta['cvid']
+            "id": self.__meta['cvid']
         }
         return await request('GET', api['url'], params=params, credential=self.credential)
 
-
     async def set_like(self, status: bool = True):
         """
         设置专栏点赞状态
@@ -416,12 +448,11 @@ class Article:
 
         api = API["operate"]["like"]
         data = {
-            "id": self.meta['cvid'],
+            "id": self.__meta['cvid'],
             "type": 1 if status else 2
         }
         return await request('POST', api['url'], data=data, credential=self.credential)
 
-
     async def set_favorite(self, status: bool = True):
         """
         设置专栏收藏状态
@@ -433,28 +464,41 @@ class Article:
 
         api = API["operate"]["add_favorite"] if status else API["operate"]["del_favorite"]
         data = {
-            "id": self.meta['cvid']
+            "id": self.__meta['cvid']
         }
         return await request('POST', api['url'], data=data, credential=self.credential)
 
-
     async def add_coins(self):
         """
-        给专栏投币
+        给专栏投币，目前只能投一个
         """
         self.credential.raise_for_no_sessdata()
 
         upid = (await self.get_info())["mid"]
         api = API["operate"]["coin"]
         data = {
-            "aid": self.meta['cvid'],
+            "aid": self.__meta['cvid'],
             "multiply": 1,
             "upid": upid,
             "avtype": 2
         }
         return await request('POST', api['url'], data=data, credential=self.credential)
 
-class ParagraphNode:
+
+class Node:
+    def __init__(self):
+        pass
+
+    @overload
+    def markdown(self):
+        pass
+
+    @overload
+    def json(self):
+        pass
+
+
+class ParagraphNode(Node):
     def __init__(self):
         self.children = []
         self.align = 'left'
@@ -469,7 +513,8 @@ class ParagraphNode:
             "children": list(map(lambda x: x.json(), self.children))
         }
 
-class HeadingNode:
+
+class HeadingNode(Node):
     def __init__(self):
         self.children = []
 
@@ -486,7 +531,7 @@ class HeadingNode:
         }
 
 
-class BlockquoteNode:
+class BlockquoteNode(Node):
     def __init__(self):
         self.children = []
 
@@ -505,7 +550,7 @@ class BlockquoteNode:
         }
 
 
-class ItalicNode:
+class ItalicNode(Node):
     def __init__(self):
         self.children = []
 
@@ -521,7 +566,8 @@ class ItalicNode:
             "children": list(map(lambda x: x.json(), self.children))
         }
 
-class BoldNode:
+
+class BoldNode(Node):
     def __init__(self):
         self.children = []
 
@@ -538,7 +584,7 @@ class BoldNode:
         }
 
 
-class DelNode:
+class DelNode(Node):
     def __init__(self):
         self.children = []
 
@@ -554,7 +600,8 @@ class DelNode:
             "children": list(map(lambda x: x.json(), self.children))
         }
 
-class UlNode:
+
+class UlNode(Node):
     def __init__(self):
         self.children = []
 
@@ -568,7 +615,7 @@ class UlNode:
         }
 
 
-class OlNode:
+class OlNode(Node):
     def __init__(self):
         self.children = []
 
@@ -584,7 +631,8 @@ class OlNode:
             "children": list(map(lambda x: x.json(), self.children))
         }
 
-class LiNode:
+
+class LiNode(Node):
     def __init__(self):
         self.children = []
 
@@ -597,9 +645,10 @@ class LiNode:
             "children": list(map(lambda x: x.json(), self.children))
         }
 
-class ColorNode:
+
+class ColorNode(Node):
     def __init__(self):
-        self.color = Color('000000')
+        self.color = '000000'
         self.children = []
 
     def markdown(self):
@@ -608,12 +657,12 @@ class ColorNode:
     def json(self):
         return {
             "type": "ColorNode",
-            "color": self.color.get_hex_color(),
+            "color": self.color,
             "children": list(map(lambda x: x.json(), self.children))
         }
 
 
-class FontSizeNode:
+class FontSizeNode(Node):
     def __init__(self):
         self.size = 16
         self.children = []
@@ -628,10 +677,10 @@ class FontSizeNode:
             "children": list(map(lambda x: x.json(), self.children))
         }
 
+# 特殊节点，即无子节点
 
-## 特殊节点，即无子节点
 
-class TextNode:
+class TextNode(Node):
     def __init__(self, text: str):
         self.text = text
 
@@ -645,7 +694,7 @@ class TextNode:
         }
 
 
-class ImageNode:
+class ImageNode(Node):
     def __init__(self):
         self.url = ''
         self.alt = ''
@@ -661,7 +710,8 @@ class ImageNode:
             "alt": self.alt
         }
 
-class LatexNode:
+
+class LatexNode(Node):
     def __init__(self):
         self.code = ''
 
@@ -679,7 +729,8 @@ class LatexNode:
             "code": self.code
         }
 
-class CodeNode:
+
+class CodeNode(Node):
     def __init__(self):
         self.code = ''
         self.lang = ''
@@ -697,7 +748,7 @@ class CodeNode:
 # 卡片
 
 
-class VideoCardNode:
+class VideoCardNode(Node):
     def __init__(self):
         self.aid = 0
 
@@ -711,7 +762,7 @@ class VideoCardNode:
         }
 
 
-class ArticleCardNode:
+class ArticleCardNode(Node):
     def __init__(self):
         self.cvid = 0
 
@@ -725,7 +776,7 @@ class ArticleCardNode:
         }
 
 
-class BangumiCardNode:
+class BangumiCardNode(Node):
     def __init__(self):
         self.epid = 0
 
@@ -739,7 +790,7 @@ class BangumiCardNode:
         }
 
 
-class MusicCardNode:
+class MusicCardNode(Node):
     def __init__(self):
         self.auid = 0
 
@@ -753,7 +804,7 @@ class MusicCardNode:
         }
 
 
-class ShopCardNode:
+class ShopCardNode(Node):
     def __init__(self):
         self.pwid = 0
 
@@ -767,7 +818,7 @@ class ShopCardNode:
         }
 
 
-class ComicCardNode:
+class ComicCardNode(Node):
     def __init__(self):
         self.mcid = 0
 
@@ -781,7 +832,7 @@ class ComicCardNode:
         }
 
 
-class LiveCardNode:
+class LiveCardNode(Node):
     def __init__(self):
         self.room_id = 0
 
@@ -795,7 +846,7 @@ class LiveCardNode:
         }
 
 
-class AnchorNode:
+class AnchorNode(Node):
     def __init__(self):
         self.url = ''
         self.text = ''
@@ -812,7 +863,7 @@ class AnchorNode:
         }
 
 
-class SeparatorNode:
+class SeparatorNode(Node):
     def __init__(self):
         pass
 
@@ -823,4 +874,3 @@ class SeparatorNode:
         return {
             "type": "SeparatorNode"
         }
-
