@@ -7,9 +7,7 @@ bilibili_api.video
 from copy import copy
 from enum import Enum
 from typing import Coroutine
-import aiohttp
 import re
-import json
 import datetime
 import asyncio
 import aiohttp
@@ -30,13 +28,11 @@ from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
 from .utils.utils import get_api
 from .utils.network import request, get_session
 from .utils.Danmaku import Danmaku
-from .utils.Color import Color
 from .utils.BytesReader import BytesReader
 from .utils.AsyncEvent import AsyncEvent
 
 API = get_api("video")
 
-
 class Video:
     """
     视频类，各种对视频的操作均在里面。
@@ -59,13 +55,10 @@ class Video:
             raise ArgsException("请至少提供 bvid 和 aid 中的其中一个参数。")
 
         # 未提供 credential 时初始化该类
-        if credential is None:
-            self.credential = Credential()
-        else:
-            self.credential = credential
+        self.credential: Credential = Credential() if credential is None else credential
 
         # 用于存储视频信息，避免接口依赖视频信息时重复调用
-        self.__info = None
+        self.__info: dict or None = None
 
     def set_bvid(self, bvid: str):
         """
@@ -362,7 +355,7 @@ class Video:
             reader_ = BytesReader(stream)
             data = {}
             while not reader_.has_end():
-                t = reader_.byte() >> 3
+                t = reader_.varint() >> 3
                 if t == 1:
                     data['page_size'] = reader_.varint()
                 elif t == 2:
@@ -375,7 +368,7 @@ class Video:
             reader_ = BytesReader(stream)
             data = {}
             while not reader_.has_end():
-                t = reader_.byte() >> 3
+                t = reader_.varint() >> 3
                 if t == 1:
                     data['rec_flag'] = reader_.varint()
                 elif t == 2:
@@ -390,7 +383,7 @@ class Video:
             reader_ = BytesReader(stream)
             data = {}
             while not reader_.has_end():
-                t = reader_.byte() >> 3
+                t = reader_.varint() >> 3
                 if t == 1:
                     data['id'] = reader_.varint()
                 elif t == 2:
@@ -419,7 +412,7 @@ class Video:
             reader_ = BytesReader(stream)
             data = {}
             while not reader_.has_end():
-                t = reader_.byte() >> 3
+                t = reader_.varint() >> 3
 
                 if t == 1:
                     data['dm_switch'] = reader_.bool()
@@ -466,7 +459,7 @@ class Video:
             return data
 
         while not reader.has_end():
-            type_ = reader.byte() >> 3
+            type_ = reader.varint() >> 3
 
             if type_ == 1:
                 json_data['state'] = reader.varint()
@@ -503,7 +496,7 @@ class Video:
 
         Args:
             page_index (int)                    : 分 p 号，从 0 开始。
-            data       (datetime.Date, optional): 指定日期后为获取历史弹幕，精确到年月日。Defaults to None.
+            date       (datetime.Date, optional): 指定日期后为获取历史弹幕，精确到年月日。Defaults to None.
 
         Returns:
             List[Danmaku]: Danmaku 类的列表。
@@ -562,7 +555,7 @@ class Video:
 
             reader = BytesReader(data)
             while not reader.has_end():
-                type_ = reader.byte() >> 3
+                type_ = reader.varint() >> 3
                 if type_ != 1:
                     raise ResponseException("解析响应数据错误")
 
@@ -571,27 +564,24 @@ class Video:
                 dm_reader = BytesReader(dm_pack_data)
 
                 while not dm_reader.has_end():
-                    data_type = dm_reader.byte() >> 3
+                    data_type = dm_reader.varint() >> 3
 
                     if data_type == 1:
                         dm.id = dm_reader.varint()
                     elif data_type == 2:
-                        dm.dm_time = datetime.timedelta(
-                            seconds=dm_reader.varint() / 1000)
+                        dm.dm_time = dm_reader.varint() / 1000
                     elif data_type == 3:
                         dm.mode = dm_reader.varint()
                     elif data_type == 4:
                         dm.font_size = dm_reader.varint()
                     elif data_type == 5:
-                        dm.color = Color()
-                        dm.color.set_dec_color(dm_reader.varint())
+                        dm.color = hex(dm_reader.varint())[2:]
                     elif data_type == 6:
                         dm.crc32_id = dm_reader.string()
                     elif data_type == 7:
                         dm.text = dm_reader.string()
                     elif data_type == 8:
-                        dm.send_time = datetime.datetime.fromtimestamp(
-                            dm_reader.varint())
+                        dm.send_time = dm_reader.varint()
                     elif data_type == 9:
                         dm.weight = dm_reader.varint()
                     elif data_type == 10:
@@ -620,7 +610,7 @@ class Video:
         """
         self.credential.raise_for_no_sessdata()
 
-        page_id = self.__get_page_id_by_index(page_index)
+        page_id = await self.__get_page_id_by_index(page_index)
         api = API["danmaku"]["get_history_danmaku_index"]
         params = {
             "oid": page_id,
@@ -676,8 +666,8 @@ class Video:
             "msg": danmaku.text,
             "aid": self.get_aid(),
             "bvid": self.get_bvid(),
-            "progress": int(danmaku.dm_time.seconds * 1000),
-            "color": danmaku.color.get_dec_color(),
+            "progress": int(danmaku.dm_time * 1000),
+            "color": int(danmaku.color, 16),
             "fontsize": danmaku.font_size.value,
             "pool": pool,
             "mode": danmaku.mode.value,
@@ -864,7 +854,6 @@ class Video:
         }
         return await request("POST", url=api["url"], data=data, credential=self.credential)
 
-
 class VideoOnlineMonitor(AsyncEvent):
     """
     视频在线人数实时监测。
@@ -1158,18 +1147,18 @@ class VideoOnlineMonitor(AsyncEvent):
 
 class VideoUploaderPageObject:
     """
-    分 P 对象。
+    视频上传分 P 对象。
     """
 
     def __init__(self, video_stream: io.BufferedIOBase, title: str, video_format: str = "mp4", description: str = ""):
         """
         Args:
-            video_stream (io.BufferedIOBase): 分 P 视频流。可以是 open() 返回的 FileIO 对象。
+            video_stream (io.BufferedIOBase): 分 P 视频流。可以是 `open()` 返回的 FileIO 对象。
             title        (str)              : 分 P 标题。
-            video_format (str)              : 分 P 的视频格式。可以是 mp4, mkv, mov, wmv。 Default to “mp4”。
+            video_format (str)              : 分 P 的视频格式。可以是 mp4, mkv, mov, wmv。 Default to "mp4"。
             description  (str, optional)    : 分 P 描述。 Defaults to ""。
         """
-        self.stream = video_stream
+        self.__stream = video_stream
         self.title = title
         self.video_format = video_format
         self.description = description
@@ -1180,31 +1169,41 @@ class VideoUploaderPageObject:
         获取总大小。
 
         Returns:
-            int: 文件总大小。
+            int: 视频流总大小。
         """
         if self.__total_size is None:
-            self.__total_size = len(self.stream.read())
+            self.__total_size = len(self.__stream.read())
         return self.__total_size
 
+    def get_stream(self):
+        """
+        获取视频流。
+
+        Returns:
+            io.BufferedIOBase: 视频流
+        """
+        return self.__stream
+
 
 class VideoUploader(AsyncEvent):
     """
     视频上传。任何上传中的出错将会直接抛出错误并终止上传。
 
-    Events:
-        COVER_SUCCESS   封面上传成功。CallbackData：封面 URL。
-        BEGIN           开始上传分 P。CallbackData：VideoUploaderPageObject
-        CHUNK_BEGIN     开始上传分 P 分块。
-                        CallbackData：
-                            VideoUploaderPageObject,
-                            {
-                                "chunk_index": "int: 分块编号",
-                                "total_chunk": "int: 总共有多少个分块",
-                                "start": "int: 该 chunk 数据开始位置",
-                                "end": "int: 该 chunk 数据结束位置"
-                            }
-        CHUNK_END       分块上传结束。CallbackData：VideoUploaderPageObject
-        END             分 P 上传结束。CallbackData：VideoUploaderPageObject
+    | name         | description       | callback                                                     |
+    | ------------ | ----------------- | ------------------------------------------------------------ |
+    | COVER_BEGIN  | 准备上传封面      | None                                                         |
+    | COVER_END    | 封面上传成功      | str: 封面 URL。                                              |
+    | PAGE_BEGIN   | 开始上传分 P      | VideoUploaderPageObject: 当前分 P 对象                       |
+    | CHUNK_BEGIN  | 开始上传分 P 分块 | {
+                                            "page": VideoUploaderPageObject #  分 P 对象,
+                                            "chunk_index": int,   # 区块编号
+                                            "total_chunk": int,   # 总区块数量
+                                            "range": Tuple[int, int]  # 数据范围
+                                        } |
+    | CHUNK_END    | 分块上传结束      | 同 CHUNK_BEGIN                                               |
+    | PAGE_END     | 分 P 上传结束     | VideoUploaderPageObject: 当前分 P 对象                       |
+    | SUBMIT_BEGIN | 准备提交视频      | dict: 准备提交的数据                                         |
+    | SUBMIT_END   | 提交视频结束      | dict: 调用 API 返回结果                                      |
     """
 
     def __init__(self,
@@ -1218,7 +1217,7 @@ class VideoUploader(AsyncEvent):
             cover      (io.BufferedIOBase)            : 封面 io 类，比如调用 open() 打开文件后的返回值。
             cover_type (str)                          : 封面数据 MIME 类型。常见类型对照 jpg: image/jpeg, png: image/png
             pages      (List[VideoUploaderPageObject]): 分 P 视频列表。
-            config     (dict)                         : 设置，格式参照 self.set_config()
+            config     (dict)                         : 视频信息，格式参照 self.set_config()
             credential (Credential)                   : Credential 类。
         """
         super().__init__()
@@ -1273,7 +1272,7 @@ class VideoUploader(AsyncEvent):
         ```
 
         Args:
-            config (dict): 上传配置
+            config (dict): 视频信息
         """
         if any(["videos" in config, "cover" in config]):
             raise ArgsException("不可手动设置参数：cover, videos。将会自动设置。")
@@ -1281,10 +1280,10 @@ class VideoUploader(AsyncEvent):
 
     def get_config(self):
         """
-        获取配置。
+        获取视频信息。
 
         Returns:
-            dict: 视频配置。
+            dict: 视频信息。
         """
         return copy(self.__config)
 
@@ -1296,9 +1295,10 @@ class VideoUploader(AsyncEvent):
             dict: 包含 bvid 和 aid 的字典。
         """
         # 上传封面
+        self.dispatch("COVER_BEGIN")
         cover_info = await self.__upload_cover()
         cover_url = cover_info["url"]
-        self.dispatch("COVER_SUCCESS", cover_url)
+        self.dispatch("COVER_END", cover_url)
 
         # 上传视频
         videos = []
@@ -1339,12 +1339,15 @@ class VideoUploader(AsyncEvent):
         params = {
             "csrf": self.credential.bili_jct
         }
-        return await request("POST", "https://member.bilibili.com/x/vu/web/add",
+        self.dispatch("SUBMIT_BEGIN", config)
+        resp = await request("POST", "https://member.bilibili.com/x/vu/web/add",
                              data=data,
                              params=params,
                              credential=self.credential,
                              no_csrf=True,
                              json_body=True)
+        self.dispatch("SUBMIT_END", resp)
+        return resp
 
     async def __upload_cover(self):
         """
@@ -1370,7 +1373,7 @@ class VideoUploader(AsyncEvent):
         Returns:
             str: filename，用于最后提交视频。
         """
-        self.dispatch("BEGIN", page)
+        self.dispatch("PAGE_BEGIN", page)
         # 获取上传信息
         upload_info = await self.__get_upload_info(page)
         # 最大并发数
@@ -1413,10 +1416,12 @@ class VideoUploader(AsyncEvent):
         # 初始化 chunk
         chunks = []
         remain_size = total_size
+
+        stream = page.get_stream()
         for i, offset in enumerate(chunk_offsets):
             length = chunk_size if remain_size > chunk_size else remain_size
             chunks.append(self.__upload_chunk(offset, length, total_size,
-                                              total_chunks_count, page.stream,
+                                              total_chunks_count, stream,
                                               url, auth, i, upload_id, page))
             remain_size -= length
 
@@ -1474,7 +1479,7 @@ class VideoUploader(AsyncEvent):
             data = json.loads(data)
             if data["OK"] != 1:
                 raise VideoUploadException("上传失败")
-        self.dispatch("END", page)
+        self.dispatch("PAGE_END", page)
         return filename
 
     async def __task(self, chunks: List[Coroutine]):
@@ -1515,12 +1520,12 @@ class VideoUploader(AsyncEvent):
             page               (VideoUploaderPageObject): VideoUploaderPageObject
         """
         callback_data = {
+            "page": page,
             "chunk_index": index + 1,
             "total_chunk": total_chunks_count,
-            "start": start,
-            "end": start + length
+            "range": (start, start + length)
         }
-        self.dispatch("CHUNK_BEGIN", page, callback_data)
+        self.dispatch("CHUNK_BEGIN", callback_data)
         headers = {
             "User-Agent": "Mozilla/5.0",
             "Referer": "https://member.bilibili.com",
@@ -1546,7 +1551,7 @@ class VideoUploader(AsyncEvent):
                 cookies=self.credential.get_cookies()) as resp:
 
             await resp.wait_for_close()
-        self.dispatch("CHUNK_END", page, callback_data)
+        self.dispatch("CHUNK_END", callback_data)
 
     async def __get_upload_info(self, page_object: VideoUploaderPageObject):
         """
